Author: ion
Date: Fri Jul 15 01:44:03 2011
New Revision: 52686

URL: http://svn.reactos.org/svn/reactos?rev=52686&view=rev
Log:
[KERNEL32/RTL]: Fix build.

Modified:
    trunk/reactos/dll/win32/kernel32/file/find.c
    trunk/reactos/dll/win32/kernel32/misc/utils.c
    trunk/reactos/lib/rtl/path.c

Modified: trunk/reactos/dll/win32/kernel32/file/find.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/dll/win32/kernel32/file/find.c?rev=52686&r1=52685&r2=52686&view=diff
==============================================================================
--- trunk/reactos/dll/win32/kernel32/misc/utils.c [iso-8859-1] (original)
+++ trunk/reactos/dll/win32/kernel32/misc/utils.c [iso-8859-1] Fri Jul 15 
01:44:03 2011
@@ -424,7 +424,7 @@
              OUT PHANDLE hSection,
              IN PUNICODE_STRING ApplicationName)
 {
-    CURDIR RelativeName;
+    RTL_RELATIVE_NAME_U RelativeName;
     OBJECT_ATTRIBUTES ObjectAttributes;
     NTSTATUS Status;
     HANDLE hFile = NULL;
@@ -433,7 +433,7 @@
     DPRINT("BasepMapFile\n");
     
     /* Zero out the Relative Directory */
-    RelativeName.Handle = NULL;
+    RelativeName.ContainingDirectory = NULL;
 
     /* Find the application name */
     if (!RtlDosPathNameToNtPathName_U(lpApplicationName,
@@ -445,19 +445,19 @@
     }
 
     DPRINT("ApplicationName %wZ\n", ApplicationName);
-    DPRINT("RelativeName %wZ\n", &RelativeName.DosPath);
+    DPRINT("RelativeName %wZ\n", &RelativeName.RelativeName);
     
     /* Did we get a relative name? */
-    if (RelativeName.DosPath.Length)
-    {
-        ApplicationName = &RelativeName.DosPath;
+    if (RelativeName.RelativeName.Length)
+    {
+        ApplicationName = &RelativeName.RelativeName;
     }
 
     /* Initialize the Object Attributes */
     InitializeObjectAttributes(&ObjectAttributes,
                                ApplicationName,
                                OBJ_CASE_INSENSITIVE,
-                               RelativeName.Handle,
+                               RelativeName.ContainingDirectory,
                                NULL);
 
     /* Try to open the executable */

Modified: trunk/reactos/lib/rtl/path.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/lib/rtl/path.c?rev=52686&r1=52685&r2=52686&view=diff
==============================================================================
--- trunk/reactos/lib/rtl/path.c [iso-8859-1] (original)
+++ trunk/reactos/lib/rtl/path.c [iso-8859-1] Fri Jul 15 01:44:03 2011
@@ -1014,7 +1014,6 @@
  * @implemented
  */
 BOOLEAN
-BOOLEAN
 NTAPI
 RtlDoesFileExists_UEx(IN PCWSTR FileName,
                       IN BOOLEAN SucceedIfBusy)


Reply via email to
--- trunk/reactos/dll/win32/kernel32/file/find.c [iso-8859-1] (original)
+++ trunk/reactos/dll/win32/kernel32/file/find.c [iso-8859-1] Fri Jul 15 
01:44:03 2011
@@ -259,7 +259,7 @@
        PWSTR NtPathBuffer;
        BOOLEAN RemovedLastChar = FALSE;
        BOOL bResult;
-       CURDIR DirInfo;
+       RTL_RELATIVE_NAME_U DirInfo;
        ULONG DeviceNameInfo;
        HANDLE hDirectory = NULL;
 
@@ -292,20 +292,20 @@
        }
        PathFileName.MaximumLength = PathFileName.Length;
 
-       if (DirInfo.DosPath.Length != 0 && DirInfo.DosPath.Buffer != 
PathFileName.Buffer)
+       if (DirInfo.RelativeName.Length != 0 && DirInfo.RelativeName.Buffer != 
PathFileName.Buffer)
        {
            if (PathFileName.Buffer != NULL)
            {
                /* This is a relative path to DirInfo.Handle, adjust NtPathU! */
adjust NtPathU! */
                NtPathU.Length = NtPathU.MaximumLength =
-                   (USHORT)((ULONG_PTR)PathFileName.Buffer - 
(ULONG_PTR)DirInfo.DosPath.Buffer);
-               NtPathU.Buffer = DirInfo.DosPath.Buffer;
+                   (USHORT)((ULONG_PTR)PathFileName.Buffer - 
(ULONG_PTR)DirInfo.RelativeName.Buffer);
+               NtPathU.Buffer = DirInfo.RelativeName.Buffer;
            }
        }
        else
        {
            /* This is an absolute path, NtPathU receives the full path */
-           DirInfo.Handle = NULL;
+           DirInfo.ContainingDirectory = NULL;
            if (PathFileName.Buffer != NULL)
            {
                NtPathU.Length = NtPathU.MaximumLength =
@@ -332,12 +332,12 @@
        TRACE("lpFileName: \"%ws\"\n", lpFileName);
        TRACE("NtPathU: \"%wZ\"\n", &NtPathU);
        TRACE("PathFileName: \"%wZ\"\n", &PathFileName);
-       TRACE("RelativeTo: 0x%p\n", DirInfo.Handle);
+       TRACE("RelativeTo: 0x%p\n", DirInfo.ContainingDirectory);
 
        InitializeObjectAttributes (&ObjectAttributes,
                                    &NtPathU,
                                    OBJ_CASE_INSENSITIVE,
-                                   DirInfo.Handle,
+                                   DirInfo.ContainingDirectory,
                                    NULL);
 
        Status = NtOpenFile (&hDirectory,
@@ -292,20 +292,20 @@
            if (PathFileName.Buffer != NULL)
            {
-               /* This is a relative path to DirInfo.Handle, adjust NtPathU! */
+               /* This is a relative path to DirInfo.ContainingDirectory, 
adjust NtPathU! */
                NtPathU.Length = NtPathU.MaximumLength =

Modified: trunk/reactos/dll/win32/kernel32/misc/utils.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/dll/win32/kernel32/misc/utils.c?rev=52686&r1=52685&r2=52686&view=diff
==============================================================================